@@ -1,8 +1,10 @@
+import logging
+
 from platypush.message.event import Event
 
 
 class CameraEvent(Event):
-    """ Base class for camera events """
+    """Base class for camera events"""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -49,13 +51,13 @@ class CameraFrameCapturedEvent(CameraEvent):
     Event triggered when a camera frame has been captured
     """
 
-    disable_logging = True
-
     def __init__(self, filename=None, *args, **kwargs):
-        super().__init__(*args, filename=filename,
-                         disable_logging=kwargs.pop('disable_logging')
-                         if 'disable_logging' in kwargs else self.disable_logging,
-                         **kwargs)
+        super().__init__(
+            *args,
+            filename=filename,
+            logging_level=kwargs.pop('logging_level', logging.DEBUG),
+            **kwargs
+        )
 
 
 # vim:sw=4:ts=4:et:
