@@ -1,3 +1,4 @@
+import logging
 from typing import Optional, Dict, Any
 
 from platypush.message.event import Event
@@ -12,32 +13,39 @@ class ZwaveNetworkReadyEvent(ZwaveEvent):
     """
     Triggered when the network started on a Z-Wave adapter becomes ready.
     """
-    def __init__(self,
-                 ozw_library_version: str,
-                 python_library_version: str,
-                 zwave_library: str,
-                 node_id: int,
-                 node_version: str,
-                 home_id: int,
-                 nodes_count: int,
-                 device: Optional[str] = None,
-                 *args, **kwargs):
-        super().__init__(*args,
-                         device=device,
-                         ozw_library_version=ozw_library_version,
-                         python_library_version=python_library_version,
-                         zwave_library=zwave_library,
-                         home_id=home_id,
-                         node_id=node_id,
-                         node_version=node_version,
-                         nodes_count=nodes_count,
-                         **kwargs)
+
+    def __init__(
+        self,
+        ozw_library_version: str,
+        python_library_version: str,
+        zwave_library: str,
+        node_id: int,
+        node_version: str,
+        home_id: int,
+        nodes_count: int,
+        device: Optional[str] = None,
+        *args,
+        **kwargs
+    ):
+        super().__init__(
+            *args,
+            device=device,
+            ozw_library_version=ozw_library_version,
+            python_library_version=python_library_version,
+            zwave_library=zwave_library,
+            home_id=home_id,
+            node_id=node_id,
+            node_version=node_version,
+            nodes_count=nodes_count,
+            **kwargs
+        )
 
 
 class ZwaveNetworkStoppedEvent(ZwaveEvent):
     """
     Triggered when a Z-Wave network is stopped.
     """
+
     pass
 
 
@@ -45,6 +53,7 @@ class ZwaveNetworkErrorEvent(ZwaveEvent):
     """
     Triggered when an error occurs on the Z-Wave network.
     """
+
     pass
 
 
@@ -52,6 +61,7 @@ class ZwaveNetworkResetEvent(ZwaveEvent):
     """
     Triggered when a Z-Wave network is reset.
     """
+
     pass
 
 
@@ -59,6 +69,7 @@ class ZwaveNodeEvent(ZwaveEvent):
     """
     Generic Z-Wave node event class.
     """
+
     def __init__(self, node: Dict[str, Any], *args, **kwargs):
         super().__init__(*args, node=node, **kwargs)
 
@@ -67,6 +78,7 @@ class ZwaveNodeAddedEvent(ZwaveNodeEvent):
     """
     Triggered when a node is added to the network.
     """
+
     pass
 
 
@@ -74,6 +86,7 @@ class ZwaveNodeRemovedEvent(ZwaveNodeEvent):
     """
     Triggered when a node is removed from the network.
     """
+
     pass
 
 
@@ -81,6 +94,7 @@ class ZwaveNodeRenamedEvent(ZwaveNodeEvent):
     """
     Triggered when a node is renamed.
     """
+
     pass
 
 
@@ -88,6 +102,7 @@ class ZwaveNodeReadyEvent(ZwaveNodeEvent):
     """
     Triggered when a node is ready.
     """
+
     pass
 
 
@@ -95,6 +110,7 @@ class ZwaveNodeAsleepEvent(ZwaveNodeEvent):
     """
     Triggered when a node goes in sleep mode.
     """
+
     pass
 
 
@@ -102,6 +118,7 @@ class ZwaveNodeAwakeEvent(ZwaveNodeEvent):
     """
     Triggered when a node goes back into awake mode.
     """
+
     pass
 
 
@@ -109,8 +126,11 @@ class ZwaveNodeGroupEvent(ZwaveNodeEvent):
     """
     Triggered when a node is associated/de-associated to a group.
     """
+
     def __init__(self, group_index: Optional[int] = None, *args, **kwargs):
-        kwargs['disable_logging'] = True
+        # ZwaveNodeGroupEvent can be quite verbose, so we only report them if
+        # debug logging is enabled
+        kwargs['logging_level'] = logging.DEBUG
         super().__init__(*args, group_index=group_index, **kwargs)
 
 
@@ -118,6 +138,7 @@ class ZwaveNodeSceneEvent(ZwaveNodeEvent):
     """
     Triggered when a scene is activated on a node.
     """
+
     def __init__(self, scene_id: int, *args, **kwargs):
         super().__init__(*args, scene_id=scene_id, **kwargs)
 
@@ -126,6 +147,7 @@ class ZwaveNodePollingEnabledEvent(ZwaveNodeEvent):
     """
     Triggered when the polling of a node is successfully turned on.
     """
+
     pass
 
 
@@ -133,6 +155,7 @@ class ZwaveNodePollingDisabledEvent(ZwaveNodeEvent):
     """
     Triggered when the polling of a node is successfully turned off.
     """
+
     pass
 
 
@@ -140,6 +163,7 @@ class ZwaveButtonCreatedEvent(ZwaveNodeEvent):
     """
     Triggered when a button is added to the network.
     """
+
     pass
 
 
@@ -147,6 +171,7 @@ class ZwaveButtonRemovedEvent(ZwaveNodeEvent):
     """
     Triggered when a button is removed from the network.
     """
+
     pass
 
 
@@ -154,6 +179,7 @@ class ZwaveButtonOnEvent(ZwaveNodeEvent):
     """
     Triggered when a button is pressed.
     """
+
     pass
 
 
@@ -161,6 +187,7 @@ class ZwaveButtonOffEvent(ZwaveNodeEvent):
     """
     Triggered when a button is released.
     """
+
     pass
 
 
@@ -168,8 +195,11 @@ class ZwaveValueEvent(ZwaveEvent):
     """
     Abstract class for Z-Wave value events.
     """
+
     def __init__(self, node: Dict[str, Any], value: Dict[str, Any], *args, **kwargs):
-        kwargs['disable_logging'] = True
+        # ZwaveValueEvent can be quite verbose, so we only report them if debug
+        # logging is enabled
+        kwargs['logging_level'] = logging.DEBUG
         super().__init__(*args, node=node, value=value, **kwargs)
 
 
@@ -177,6 +207,7 @@ class ZwaveValueAddedEvent(ZwaveValueEvent):
     """
     Triggered when a value is added to a node on the network.
     """
+
     pass
 
 
@@ -184,6 +215,7 @@ class ZwaveValueChangedEvent(ZwaveValueEvent):
     """
     Triggered when a value of a node on the network changes.
     """
+
     pass
 
 
@@ -191,6 +223,7 @@ class ZwaveValueRefreshedEvent(ZwaveValueEvent):
     """
     Triggered when a value of a node on the network is refreshed.
     """
+
     pass
 
 
@@ -198,6 +231,7 @@ class ZwaveValueRemovedEvent(ZwaveValueEvent):
     """
     Triggered when a value of a node on the network is removed.
     """
+
     pass
 
 
@@ -205,6 +239,7 @@ class ZwaveNodeQueryCompletedEvent(ZwaveEvent):
     """
     Triggered when all the nodes on the network have been queried.
     """
+
     pass
 
 
@@ -212,16 +247,33 @@ class ZwaveCommandEvent(ZwaveEvent):
     """
     Triggered when a command is received on the network.
     """
-    def __init__(self, state: str, state_description: str, error: Optional[str] = None,
-                 error_description: Optional[str] = None, node: Optional[Dict[str, Any]] = None, *args, **kwargs):
-        super().__init__(*args, state=state, state_description=state_description,
-                         error=error, error_description=error_description, node=node, **kwargs)
+
+    def __init__(
+        self,
+        state: str,
+        state_description: str,
+        error: Optional[str] = None,
+        error_description: Optional[str] = None,
+        node: Optional[Dict[str, Any]] = None,
+        *args,
+        **kwargs
+    ):
+        super().__init__(
+            *args,
+            state=state,
+            state_description=state_description,
+            error=error,
+            error_description=error_description,
+            node=node,
+            **kwargs
+        )
 
 
 class ZwaveCommandWaitingEvent(ZwaveCommandEvent):
     """
     Triggered when a command is waiting for a message to proceed.
     """
+
     pass
 
 
